//
// main application program template for the usb hid bootloader
//
program main_program

//
//-----------------------------------------------------------------------------
// hardware platforms (uncomment one section/customize for your hardware)
// the USER_INIT file for each platform contains the pic config settings, 
// userInit() routine, LED definitions, and any misc setup info
//-----------------------------------------------------------------------------
//
{
// Sparkfun USB Bit Whacker v1.2 18F2553 DEV-00762 (www.sparkfun.com)
device = 18F2553        // 18F2550 family
clock = 48
#option USER_INIT = "UBW_2553.bas"
}

{
// Microchip LPC (LowPinCount) USB dev kit 18F14K50 DM164127
device = 18F14K50
clock = 48
#option USER_INIT = "LPC_14K50.bas"
}

{
// Microchip USB PIM 18F47J53 MA180029
device = 18F47J53
clock = 48
#option USER_INIT = "PIM_47J53.bas"
// J series doesn't support these features
#option INCLUDE_USERID_DATA = false
#option INCLUDE_EEPROM_DATA = false
}

{
// Microchip USB PIM 18F87J94 MA180033
device = 18F87J94
clock = 64          // clock setup supports 64MHz or 32MHz
#option USER_INIT = "PIM_87J94.bas"
// J series doesn't support these features
#option INCLUDE_USERID_DATA = false
#option INCLUDE_EEPROM_DATA = false
}

'{
// Microchip PICDEM FS USB dev board 18F45K50 DM163025-1
device = 18F45K50
clock = 48
#option USER_INIT = "PICDEM_FS_45K50.bas"
'}

//
//-----------------------------------------------------------------------------
// program build options (ORG_RESET)
//-----------------------------------------------------------------------------
//
// application program start address
// ** THIS MUST MATCH THE BOOTLOADER SETTING **
#define APP_PROGRAM_START = $1000     // 4096

// relocate reset, int vectors, and main program
#option org_reset = APP_PROGRAM_START

//
//-----------------------------------------------------------------------------
// SF startup initialization
//-----------------------------------------------------------------------------
// note: include startup.bas first before any other files as it has some 
// initialization that needs to be done right at startup
// this is VERY important if you're using a bootloader
//
// set WDT option to allow clrwdt() to tickle the wdt (since it may be enabled), 
// but do not change the config setting
//
#option WDT = true
include "startup.bas"

//
//-----------------------------------------------------------------------------
// config settings
// Note: The bootloader provides the ability to reprogram the config settings,
// so it's possible to build the bootloader and the application with different
// settings. However, this can be very dangerous and can result in non-functional
// operation, or even a system unable to boot. It's probably best to just set 
// them once here, otherwise use great caution.
//-----------------------------------------------------------------------------
//
// include the USER_INIT file specified above
include USER_INIT

// the userio module maps some of the hardware defined in the USER_INIT
// file to some friendly names, including UserInit()/Exit(), UserBootselect(),
// and UserLedOn()/Off()/Toggle()
include "userio.bas"

//
//-----------------------------------------------------------------------------
// IPC module (optional)
// used for application->bootloader communications
// If used, this file MUST be included before any other libraries/startup code
// that might modify the RCON register
//-----------------------------------------------------------------------------
//
#option USE_IPC = true
include "ipcBootloader.bas"

//
//-----------------------------------------------------------------------------
// main application code
//-----------------------------------------------------------------------------
//
dim b as byte

main:
    IPC.reset_rcon()
    UserInit()
    
    b = 0
  
    while (true)
        UserLedToggle()
        delayms(500)
        
        // check the boot select switch
        // if it's pressed, wait until it's released and then invoke the bootloader
        if (UserBootselect()) then
            repeat
                delayms(100)                // toggle LED rapidly until sw is released...
                UserLedToggle()
            until (UserBootselect() = false)
            UserExit()
          #if (USE_IPC)                     // set flag to let bootloader know we want it to run
            IPC.run_bootloader()
          #else
            IPC.reset()                     // just do a normal reset... we should end up back here
          #endif
        endif
    end while
    
end program
