//
//-----------------------------------------------------------------------------
// Name    : main_hid.bas
// Author  : Jerry Messina
// Date    : 1/1/2015
// Version : 1.4.3
// Notes   : USB HID main application example
//  HID test application for use w/USB bootloader 
//-----------------------------------------------------------------------------
//
program main_HID

//
//-----------------------------------------------------------------------------
// hardware platforms (uncomment one section/customize for your hardware)
// the USER_INIT file for each platform contains the pic config settings, 
// userInit() routine, LED definitions, and any misc setup info
//-----------------------------------------------------------------------------
//
{
// Sparkfun USB Bit Whacker v1.2 18F2553 DEV-00762 (www.sparkfun.com)
device = 18F2553        // 18F2550 family
clock = 48
#option USER_INIT = "UBW_2553.bas"
}

{
// Microchip LPC (LowPinCount) USB dev kit 18F14K50 DM164127
device = 18F14K50
clock = 48
#option USER_INIT = "LPC_14K50.bas"
}

'{
// Microchip USB PIM 18F47J53 MA180029
device = 18F47J53
clock = 48
#option USER_INIT = "PIM_47J53.bas"
'}

{
// Microchip USB PIM 18F87J94 MA180033
device = 18F87J94
clock = 64          // clock setup supports 64MHz or 32MHz
#option USER_INIT = "PIM_87J94.bas"
}

{
// Microchip PICDEM FS USB dev board 18F45K50 DM163025-1
device = 18F45K50
clock = 48
#option USER_INIT = "PICDEM_FS_45K50.bas"
}

//
//-----------------------------------------------------------------------------
// hardware setup
//-----------------------------------------------------------------------------
//
// include the USER_INIT file specified above
include USER_INIT

// application program start address
// ** THIS MUST MATCH THE BOOTLOADER SETTING **
#define APP_PROGRAM_START = $1000     // 4096
#option org_reset = APP_PROGRAM_START

//
//-----------------------------------------------------------------------------
// SF startup initialization
//-----------------------------------------------------------------------------
// note: include startup.bas first before any other files as it has some 
// initialization that needs to be done right at startup
// this is VERY important if you're using a bootloader
//
// set WDT option to allow clrwdt() to tickle the wdt (since it may be enabled), 
// but do not change the config setting
//
#option WDT = true
include "startup.bas"

//
//-----------------------------------------------------------------------------
// IPC module (optional)
// used for application->bootloader communications
// If used, this file MUST be included before any other libraries/startup code
// that might modify the RCON register
//-----------------------------------------------------------------------------
//
#option USE_IPC = true
include "ipcBootloader.bas"

//
//-----------------------------------------------------------------------------
// USB options and includes
//-----------------------------------------------------------------------------
//
// interrupt/polled mode (true=interrupt, false=polled)
// note: this option defaults to true in USBConfig
#option USB_SERVICE = true

// import USB modules...
include "usbhid.bas"

// leds, sw, etc
include "userio.bas"

// main program

//
//-----------------------------------------------------------------------------
// example 1 - generic text reports
// use the tool MikroE USB HIDTerminal (http://www.mikroe.com/upld/hidterminal.zip)
//-----------------------------------------------------------------------------
//
userInit()      // hdw specific pic init
IPC.reset_rcon()

// wait to connect to USB...
UserLedOff()
repeat
    USBservice()        // if using interrupts, calls to USBService() will be ignored
until (HID.Attached)
UserLedOn()

// main program loop
// read report messages and send/echo response
while (true)
    if (HID.Attached) then
        high(LED2)
    else
        low(LED2)
    endif

    // see if there's HID data...
    if (HID.DataAvailable()) then
        UserLedOn()                 // flash led to indicate we've got a packet
        HID.ReadReport()            // read incoming report
        TXreport.b = RXreport.b     // copy report data packet
        HID.WriteReport()           // echo it
        UserLedOff()
    endif

    // check the boot select switch
    // if it's pressed, wait until it's released and then invoke the bootloader
    if (UserBootselect()) then
        repeat
            delayms(100)                // toggle LED rapidly until sw is released...
            UserLedToggle()
        until (UserBootselect() = false)
        UserExit()
        IPC.run_bootloader()    // set flag to let bootloader know we want it to run
    endif

    // if the USB_SERVICE option has been disabled, you MUST poll the USB connection
    // every 1ms or so to keep it alive and handle pending transactions on the bus...
    USBservice()
end while

end program
