//
//***************************************************************************
// Name    : USBConfig.bas                                                  *
// Author  : David John Barker                                              *
// Notice  : Copyright (c) 2007 Mecanique                                   *
//         : All Rights Reserved                                            *
// Date    : 12/01/2007                                                     *
// Version : 1.4 Removed USB_EXTENDED_RAM (see usbmem.bas)                  *
//         : 1.1 Removed USB_SERVICE_US as ISR now uses USB interrupts      *
//         : 1.0 Release                                                    *
// Notes   : USB configuration options                                      *
//         : ==================== DO NOT EDIT THIS FILE =================== *
//         : Change the options FROM YOU MAIN PROGRAM. For example,         *
//         : #option USB_VID = $1234                                        *
//         : This will AUTOMATICALLY override these default values. DONT    *
//         : FORGET to add options BEFORE any include files!!               *
//***************************************************************************
//
module USBConfig

#option SHOW_USB_BUILD_MSGS = false

// ***************************************************************************
// device version (device_dsc)
// ***************************************************************************
#option USB_DEVICE_VERSION = $0110 // (BCD)
#if not (USB_DEVICE_VERSION in (0 to 65535))
  #error USB_DEVICE_VERSION, "Invalid option. USB_DEVICE_VERSION must be between 0 and 65535."
#endif

// ***************************************************************************
// descriptor string index (device_desc)
// ***************************************************************************
#define USB_MANUFACTURER_INDEX = 1
#define USB_PRODUCT_INDEX      = 2
#variable USB_SERIAL_INDEX     = 0

#option USB_HAVE_SERIAL_STRING = false
#if not (USB_HAVE_SERIAL_STRING in (true, false))
  #error USB_HAVE_SERIAL_STRING, "Invalid option. USB_HAVE_SERIAL_STRING must be TRUE or FALSE."
#endif
#if USB_HAVE_SERIAL_STRING
  #variable USB_SERIAL_INDEX = 3
#endif

// ***************************************************************************
// bus power (cfg01)
// ***************************************************************************
#option USB_BUS_POWER = 50 // x2
#if not (USB_BUS_POWER in (50 to 250))
  #error USB_BUS_POWER, "Invalid option. USB_BUS_POWER must be between 50 and 250."
#endif

// ***************************************************************************
// link in HID code option...
// ***************************************************************************
#option USB_USE_HID = false
#if not (USB_USE_HID in (true, false))
   #error USB_USE_HID, "Invalid option. USB_USE_HID must be TRUE or FALSE."
#endif

// ***************************************************************************
// link in CDC code option...
// ***************************************************************************
#option USB_USE_CDC = false
#if not (USB_USE_CDC in (true, false))
  #error USB_USE_CDC, "Invalid option. USB_USE_CDC must be TRUE or FALSE."
#endif

// ***************************************************************************
// default option for CDC...
// ***************************************************************************
#if (USB_USE_CDC)
  #option USB_DESCRIPTOR = "CDCDescriptor.bas"     // name of descriptor file
  #option USB_VID = $1781                          // VID - 6017 is Mecanique
  #option USB_PID = $07D1                          // PID - 2001
  #define MAX_EP_NUMBER = 3                        // UEP1 minimum, up to USB_ENDPOINT_REGISTERS   'usbcfg.h

// ***************************************************************************
// default options for HID...
// ***************************************************************************
#elseif (USB_USE_HID)
  #option USB_DESCRIPTOR = "HIDDescriptor.bas"     // name of descriptor file
  #option USB_VID = $1781                          // VID - 6017 is Mecanique
  #option USB_PID = $07D0                          // PID - 2000
  #define MAX_EP_NUMBER = 1                        // UEP1 minimum, up to USB_ENDPOINT_REGISTERS   'usbcfg.h
#else       // USB_USE_CDC and USB_USE_HID are false
  #error "must select either HID or CDC"
#endif

// MAX_EP_NUMBER must equal the highest endpoint number used in the project.
// For example, if the highest endpoint number used is endpoint 5, then MAX_EP_NUMBER
// should equal five. This definition is used mainly to allocate the buffer descriptor
// registers

// ***************************************************************************
// verify VID...
// ***************************************************************************
#if not (USB_VID in (0 to 65535))
  #error USB_VID, "Invalid option. USB_VID must be between 0 and 65535."
#endif

// ***************************************************************************
// verify PID...
// ***************************************************************************
#if not (USB_PID in (0 to 65535))
  #error USB_PID, "Invalid option. USB_PID must be between 0 and 65535."
#endif

// ***************************************************************************
// CDC options
// ***************************************************************************
#option CDC_RX_SIZE = 64    // CDCDataRX
#if not (CDC_RX_SIZE in (8, 16, 32, 64))
  #error CDC_RX_SIZE, "Invalid option. CDC_RX_SIZE must be 8, 16, 32 or 64."
#endif

#option CDC_TX_SIZE = 64    // CDCDataTX
#if not (CDC_TX_SIZE in (8, 16, 32, 64))
  #error CDC_TX_SIZE, "Invalid option. CDC_TX_SIZE must be 8, 16, 32 or 64."
#endif

// ***************************************************************************
// HID buffer size
// ***************************************************************************
#option HID_BUFFER_SIZE = 64                 // HID EP1 can be 8, 16, 32 or 64
#if not (HID_BUFFER_SIZE in (2, 4, 8, 16, 32, 64))
  #error HID_BUFFER_SIZE, "Invalid option: HID_BUFFER_SIZE size"
#endif

// will equal HID_BUFFER_SIZE unless overridden in main program...
#option HID_REPORT_BYTES_IN = HID_BUFFER_SIZE  // HID Report bytes in
#if not (HID_REPORT_BYTES_IN in (2, 4, 8, 16, 32, 64))
  #error HID_REPORT_BYTES_IN, "Invalid option: HID_REPORT_BYTES_IN size"
#endif

// will equal HID_BUFFER_SIZE unless overridden in main program...
#option HID_REPORT_BYTES_OUT = HID_BUFFER_SIZE // HID_Report bytes out
#if not (HID_REPORT_BYTES_OUT in (2, 4, 8, 16, 32, 64))
  #error HID_REPORT_BYTES_OUT, "Invalid option: HID_REPORT_BYTES_OUT size"
#endif

// ***************************************************************************
// HID EP Polling
// ***************************************************************************
#option HID_EP_OUT_POLLING_MS = 1   // HID - EP01 - 1ms (EP01Out)
#if not (HID_EP_OUT_POLLING_MS in (1 to 10))
  #error HID_EP_OUT_POLLING_MS, "Invalid option. HID_EP_OUT_POLLING_MS must be between 1 and 10."
#endif

#option HID_EP_IN_POLLING_MS = 1   // HID - EP01 - 1ms (EP01In)
#if not (HID_EP_IN_POLLING_MS in (1 to 10))
  #error HID_EP_IN_POLLING_MS, "Invalid option. HID_EP_IN_POLLING_MS must be between 1 and 10."
#endif

// ***************************************************************************
// self power sensing...
// ***************************************************************************
//  If the host PC sends a GetStatus (device) request, the firmware must respond
//  and let the host know if the USB peripheral device is currently bus powered (0)
//  or self powered (1).  See chapter 9 in the official USB specifications for details
//  regarding this request.  If the peripheral device is capable of being both
//  self and bus powered, it should not return a hard coded value for this request.
//  Instead, firmware should check if it is currently self or bus powered, and
//  respond accordingly.  If the hardware has been configured like demonstrated
//  on the PICDEM FS USB Demo Board, an I/O pin can be polled to determine the
//  currently selected power source.  On the PICDEM FS USB Demo Board, "RA2"
//  is used for this purpose.  If using this feature, make sure "SELF_POWER_SENSE_IO"
//  has been set true and that an appropriate I/O pin has been mapped to it
#option USB_SELF_POWER = 0                      // 0=bus-powered, 1=self-powered
#option SELF_POWER_SENSE_IO = false                                              'usbcfg.h
#option SELF_POWER_SENSE_PIN = PORTA.2
#if IsOption(SELF_POWER_SENSE_PIN) and not IsValidPortPin(SELF_POWER_SENSE_PIN)
  #error SELF_POWER_SENSE_PIN, "Invalid option. SELF_POWER_SENSE_PIN must be a valid port pin."
#endif

#if (SELF_POWER_SENSE_IO)                                                        'io_cfg.h
  public dim self_power as SELF_POWER_SENSE_PIN.SELF_POWER_SENSE_PIN@
#else
  public const self_power = USB_SELF_POWER
#endif

#if (SHOW_USB_BUILD_MSGS)
  #if (SELF_POWER_SENSE_IO)
    #warning "enabling SELF_POWER_SENSE_IO pin"
  #endif
#endif

// ***************************************************************************
// bus sense...
// ***************************************************************************
//  The USB specifications require that USB peripheral devices must never source
//  current onto the Vbus pin.  Additionally, USB peripherals should not source
//  current on D+ or D- when the host/hub is not actively powering the Vbus line.
//  When designing a self powered (as opposed to bus powered) USB peripheral
//  device, the firmware should make sure not to turn on the USB module and D+
//  or D- pull up resistor unless Vbus is actively powered.  Therefore, the
//  firmware needs some means to detect when Vbus is being powered by the host.
//  A 5V tolerant I/O pin can be connected to Vbus (through a resistor), and
//  can be used to detect when Vbus is high (host actively powering), or low
//  (host is shut down or otherwise not supplying power).  The USB firmware
//  can then periodically poll this I/O pin to know when it is okay to turn on
//  the USB module/D+/D- pull up resistor.  When designing a purely bus powered
//  peripheral device, it is not possible to source current on D+ or D- when the
//  host is not actively providing power on Vbus. Therefore, implementing this
//  bus sense feature is optional.  This firmware can be made to use this bus
//  sense feature by making sure "USB_BUS_SENSE_IO" has been set true
#option USB_BUS_SENSE_IO = false                                                'usbcfg.h
#option USB_BUS_SENSE_PIN = PORTA.1
#if IsOption(USB_BUS_SENSE_PIN) and not IsValidPortPin(USB_BUS_SENSE_PIN)
  #error USB_BUS_SENSE_PIN, "Invalid option. USB_BUS_SENSE_PIN must be a valid port pin."
#endif

#if (USB_BUS_SENSE_IO)                                                          'io_cfg.h
  public dim usb_bus_sense as USB_BUS_SENSE_PIN.USB_BUS_SENSE_PIN@
#else
  public const usb_bus_sense = 1
#endif

#if (SHOW_USB_BUILD_MSGS)
  #if (USB_BUS_SENSE_IO)
    #warning "enabling USB_BUS_SENSE_IO pin"
  #endif
#endif

// ***************************************************************************
// Interrupt or polled mode...
// ***************************************************************************
#option USB_SERVICE = true
#if not (USB_SERVICE in (true, false))
  #error USB_SERVICE, "Invalid option. USB_SERVICE must be TRUE or FALSE."
#endif

#if (SHOW_USB_BUILD_MSGS)
  #if (USB_SERVICE = true)
    #warning "building for interrupt mode (USB_SERVICE=true)"
  #else
    #warning "building for polled mode (USB_SERVICE=false)"
  #endif
#endif      // SHOW_USB_BUILD_MSGS

// set interrupt priority level...
#if IsOption(USB_SERVICE_PRIORITY) and not (USB_SERVICE_PRIORITY in (ipLow, ipHigh))
  #error USB_SERVICE_PRIORITY, "Invalid option. Priority must be ipHigh or ipLow."
#endif
#option USB_SERVICE_PRIORITY = ipHigh

// ***************************************************************************
// Timeout between CONFIGURED_STATE and setting 'USBSystem.Connected'
// ***************************************************************************
#option USB_CONNECT_MS = 1200
#if not (USB_CONNECT_MS in (0 to 5000))
  #error USB_CONNECT_MS, "Invalid option. USB_CONNECT_MS must be between 0 and 5000 ms."
#endif

// ***************************************************************************
// does device support extended dual port RAM
// ***************************************************************************
// removed V1.4 (see usbmem.bas)

end module

