//
//-----------------------------------------------------------------------------
// Microchip LPC (LowPinCount) USB dev kit 18F14K50 DM164127 (and DM164127-2) 
//-----------------------------------------------------------------------------
//
module user_init

#define LPC_14K50

//
//-----------------------------------------------------------------------------
// config settings
//-----------------------------------------------------------------------------
//
// 18F14K50 w/12MHz external xtal
config
    // CONFIG1L
    USBDIV = OFF,           // 48MHz usb clock
    CPUDIV = NOCLKDIV,      // 48MHz cpu clock
    // CONFIG1H
    IESO = OFF,
    FCMEN = OFF,
    PCLKEN = ON,
    PLLEN = ON,             // 4x PLL enabled
    FOSC = HS,              // external 12MHz xtal
    // CONFIG2L
    BORV = 30,
    BOREN = ON,
    PWRTEN = ON,
    // CONFIG2H
    WDTPS = 2048,           // 8 secs
    WDTEN = OFF,
    // CONFIG3H
    MCLRE = ON,             // see switch S1 notes below
    HFOFST = OFF,
    // CONFIG4L
    BBSIZ = ON              // off=2K, on=4K bytes

// debugger requires powerup timer disabled
#if isoption(MPLAB_ICD) and (MPLAB_ICD)
  config PWRTEN = OFF
#endif
//
//-----------------------------------------------------------------------------
// LPC 14K50 USB development board hardware
//-----------------------------------------------------------------------------
// board can use USB bus power or self-power (via ext J9 or ICD)
// power selected via jumper J14 1-2:Vin, 2-3:Vbus
// no USB VBUS detect
// clock setup via config settings only (see above)
//
public dim LED1     as PORTC.0      // LED D1 (green)
public dim LED2     as PORTC.1      // LED D2 (green)
// switch S1 is connected to the MCLR/RA3 pin, which is normally set for MCLR
// to be able to read it as an input you must set MCLRE off
'config MCLRE = OFF
public dim INPUT_SW as PORTA.3      // sw S1 w/ext 10K pullup
'public dim INPUT_SW as PORTC.5      // sw S2 w/ext 10K pullup (DM164127-2 only)

// USB VBUS detect
#option USB_BUS_SENSE_IO = false

// power options
#option USB_SELF_POWER = 0          // 0=bus-powered, 1=self-powered
#option SELF_POWER_SENSE_IO = false

//
//-----------------------------------------------------------------------------
// userInit() - setup IO pins and other req'd regs
//-----------------------------------------------------------------------------
//
public sub userInit()
    // all digital (disable A/D on all pins)
    ANSEL = 0
    ANSELH = 0
    CM1CON0 = %00000000     ' disable comparators
    CM2CON0 = %00000000

    // init leds & switch
    low(LED1)
    low(LED2)
    input(INPUT_SW)
end sub

//
//-----------------------------------------------------------------------------
// userClockCheck() - toggle led at 1ms rate to verify clock setting
//-----------------------------------------------------------------------------
//
public sub userClockCheck()
    while(true)
        LED1 = 1
        delayus(500)
        LED1 = 0
        delayus(500)
    end while
end sub

end module
