//
//-----------------------------------------------------------------------------
// Microchip USB PIM 18F47J53 MA180029
//-----------------------------------------------------------------------------
//
module user_init

#define PIM_47J53

//
//-----------------------------------------------------------------------------
// config settings
//-----------------------------------------------------------------------------
//
// 18F47J53 w/12MHz external xtal or internal osc
config
   OSC = INTOSCPLL,         // internal osc 8MHz w/PLL
   PLLDIV = 2,              // 48MHz usb clock (96MHz/2)
   CPUDIV = OSC1,           // 48MHz cpu clock
   FCMEN = OFF,
   IESO = OFF,
   WDTEN = OFF,
   WDTPS = 2048,
   IOL1WAY = OFF

//
//-----------------------------------------------------------------------------
// Microchip 47J53 PIM hardware
//-----------------------------------------------------------------------------
// PIM can use self-power (via ICD) or USB bus power
// USB VBUS detect (USB_ATTACH RC2) via jumper JP2 1-2
// clock setup via config settings only (see above)
//
public dim LED1     as PORTE.0      // LED D1
public dim LED2     as PORTE.1      // LED D2
public dim INPUT_SW as PORTB.2      // sw S2 w/ext 15K pullup

// note: to simplify the demo code, we disable any VBUS and SENSE options
// power options
#option USB_SELF_POWER = 0          // 0=bus-powered, 1=self-powered
#option SELF_POWER_SENSE_IO = false

// USB VBUS detect
#option USB_BUS_SENSE_IO = false    ' board supports true
#option USB_BUS_SENSE_PIN = PORTC.2
dim USB_BUS_SENSE_IN as USB_BUS_SENSE_PIN.bits(USB_BUS_SENSE_PIN@)

//
//-----------------------------------------------------------------------------
// userInit() - setup IO pins and other req'd regs
//-----------------------------------------------------------------------------
//
public sub userInit()
    // all digital (disable A/D on all pins)
    ADCON0 = %00000000      ' Vdd/Vss ref
    ANCON0 = %11111111
    ANCON1 = %11111111
    CM1CON = %00000000      ' disable comparators
    CM2CON = %00000000      ' disable comparators

    // init leds & switch
    low(LED1)
    low(LED2)
    input(INPUT_SW)
    
    // usb VBUS detect
  #if (USB_BUS_SENSE_IO)
    input(USB_BUS_SENSE_IN)
  #endif
end sub

//
//-----------------------------------------------------------------------------
// userClockCheck() - toggle led at 1ms rate to verify clock setting
//-----------------------------------------------------------------------------
//
public sub userClockCheck()
    while(true)
        LED1 = 1
        delayus(500)
        LED1 = 0
        delayus(500)
    end while
end sub

end module
