//
//-----------------------------------------------------------------------------
// Microchip USB PIM 18F87J94 MA180033
//-----------------------------------------------------------------------------
//
module user_init

#define PIM_87J94

//
//-----------------------------------------------------------------------------
// config settings
//-----------------------------------------------------------------------------
//
// 18F87J94 w/internal FRC osc and PLL
  config
    FOSC     = FRCPLL,    //
    SOSCSEL  = LOW,       // SOSC circuit configured for crystal driver mode
    CLKOEN   = OFF,       // Disable clock output on RA6
    IESO     = OFF,       // Internal External (clock) Switchover
    PLLDIV   = NODIV,     // 4MHz input (from 8MHz FRC/2) provided to PLL circuit
    POSCMD   = NONE,      // Primary osc disabled, using FRC
    FSCM     = CSECMD,    // Clock switching enabled, fail safe clock monitor disabled
    BOREN    = ON,        // BOR Enabled
    BORV     = 0,         // BOR Set to "2.0V" nominal setting
    IOL1WAY  = OFF,       // IOLOCK can be set/cleared as needed with unlock sequence
    LS48MHZ  = SYSX2,     // Low Speed USB clock divider
    WDTCLK   = LPRC,      // WDT always uses INTOSC/LPRC oscillator
    WDTEN    = ON,        // WDT is controlled via the SWDTEN bit
    WINDIS   = WDTSTD,    // Normal non-window mode WDT
    VBTBOR   = OFF        // VBAT BOR disabled

//
//-----------------------------------------------------------------------------
// Microchip PIM 18F87J94 hardware
//-----------------------------------------------------------------------------
// PIM can use self-power (via ICD) or USB bus power
// USB VBUS detect (USB_ATTACH RB5) via jumper JP1 1-2
// clock setup via both config and code (see usbsfr.bas)
//
public dim LED1     as PORTE.0      // LED D1 (red)
public dim LED2     as PORTE.1      // LED D2 (red)
public dim INPUT_SW as PORTB.4      // sw S4 w/ext 15K pullup (defaults to analog AN0)

// note: to simplify the demo code, we disable any VBUS and SENSE options
// power options
#option USB_SELF_POWER = 0          // 0=bus-powered, 1=self-powered
#option SELF_POWER_SENSE_IO = false

// USB VBUS detect
#option USB_BUS_SENSE_IO = false    ' board supports true
#option USB_BUS_SENSE_PIN = PORTB.5
dim USB_BUS_SENSE_IN as USB_BUS_SENSE_PIN.bits(USB_BUS_SENSE_PIN@)

//
//-----------------------------------------------------------------------------
// userInit() - setup IO pins and other req'd regs
//-----------------------------------------------------------------------------
//
public sub userInit()
    // all digital (disable A/D on all pins)
    ANCON1 = %00000000
    ANCON2 = %00000000
    ANCON3 = %00000000
    CM1CON = %00000000      ' disable comparators
    CM2CON = %00000000
    CM3CON = %00000000

    // init leds & switch
    low(LED1)
    low(LED2)
    input(INPUT_SW)

    // usb VBUS detect
  #if (USB_BUS_SENSE_IO)
    input(USB_BUS_SENSE_IN)
  #endif
end sub

//
//-----------------------------------------------------------------------------
// userClockCheck() - toggle led at 1ms rate to verify clock setting
//-----------------------------------------------------------------------------
//
public sub userClockCheck()
    while(true)
        LED1 = 1
        delayus(500)
        LED1 = 0
        delayus(500)
    end while
end sub

end module
