//
//---------------------------------------------------------------------------
// Name    : userio.bas
// Author  : Jerry Messina
// Date    : 1/26/2015
// Version : 1.1
//         : modified to include USER_INIT files, and to use
//         : the hardware definitions there
// Notes   : user hardware definitions/routines
//         : customize to match your hardware
//---------------------------------------------------------------------------
//
module userio

// note: if you do not need the following routines, then just comment out
// the code but leave the routines themselves... they will be optimized
// away if empty 

//
//-----------------------------------------------------------------------------
// User hardware routines
//-----------------------------------------------------------------------------
//
include USER_INIT

// create alias names for the hdw defined in the USER_INIT file
dim STATUS_LED      as LED1
dim BOOTSELECT_IN   as INPUT_SW

//
//-----------------------------------------------------------------------------
// UserInit is called at program startup
//-----------------------------------------------------------------------------
// use the setup routine from the USER_INIT file
public dim UserInit as user_init.UserInit

//
//-----------------------------------------------------------------------------
// UserExit is called before exiting the loader and running the application
//-----------------------------------------------------------------------------
//
public inline sub UserExit()
    // << add code to restore any hardware registers to their power on state >>
    // << comment out code if not used >>

    input(STATUS_LED)
    input(BOOTSELECT_IN)
end sub

//
//-----------------------------------------------------------------------------
// User LED controls (optional)
//-----------------------------------------------------------------------------
//
public inline sub UserLedOn()
    // << add code to turn on an led >>
    // << comment out code if not used >>
    STATUS_LED = 1
end sub

public inline sub UserLedOff()
    // << add code to turn off an led >>
    // << comment out code if not used >>
    STATUS_LED = 0
end sub

public sub UserLedToggle()
    if (STATUS_LED = 1) then
        STATUS_LED = 0
    else
        STATUS_LED = 1
    endif
end sub

//
//-----------------------------------------------------------------------------
// UserBootselect - read user-defined IO pin or switch used for 
//                  bootloader control
//   returns TRUE - activate bootloader
//           FALSE - skip bootloader and run application
//-----------------------------------------------------------------------------
//
public inline function UserBootselect() as boolean
    // << add code to read switch or IO pin >>
    // << just return false if not used >>
    result = false              // run application
    
    if (BOOTSELECT_IN = 0) then     // read low-active IO pin
        result = true               // stay in bootloader
    endif
end function

end module
