//
//-----------------------------------------------------------------------------
// Microchip PICDEM FS USB dev board 45K50 DM163025-1
//-----------------------------------------------------------------------------
//
module user_init

#define PICDEM_FS_45K50

//
//-----------------------------------------------------------------------------
// config settings
//-----------------------------------------------------------------------------
//
// 18F45K50 w/internal osc
config
    // CONFIG1L
   CFGPLLEN = OFF,          // control PLL in code
   PLLSEL = PLL3X,          // done in code 
   CPUDIV = NOCLKDIV,
   LS48MHZ = SYS48X8,
    // CONFIG1H
   FOSC = INTOSCIO,
   PCLKEN = OFF,
   FCMEN = OFF,
   IESO = OFF,
    // CONFIG2L
   NPWRTEN = ON,
   BOREN = ON,
   BORV = 285,
   NLPBOR = OFF,
    // CONFIG2H
   WDTEN = SWON,
   WDTPS = 2048,        // 2048 * 4ms = 8 seconds
    // CONFIG3H
   PBADEN = OFF,
   MCLRE = ON

//
//-----------------------------------------------------------------------------
// Microchip PICDEM FS dev board 45K50 DM163025-1
//-----------------------------------------------------------------------------
// board can use USB bus power or self-power (via ext input)
// USB VBUS detect (USB_ATTACH RA1) and input power detect (RA2)
// clock setup via both config and code (see usbsfr.bas)
//
public dim LED1     as PORTD.0      // LED D1 (red)
public dim LED2     as PORTD.1      // LED D2 (red)
public dim INPUT_SW as PORTB.4      // sw S2 w/ext 10K pullup

// note: to simplify the demo code, we disable any VBUS and SENSE options
// power options
#option USB_SELF_POWER = 0          // 0=bus-powered, 1=self-powered
#option SELF_POWER_SENSE_IO = false     ' board supports true
#option SELF_POWER_SENSE_PIN = PORTA.2
public dim SELF_POWER_SENSE_IN as SELF_POWER_SENSE_PIN.bits(SELF_POWER_SENSE_PIN@)

// USB VBUS detect
// if power comes from the USB bus there's no point in detecting it
#if (USB_SELF_POWER = 0)
  #option USB_BUS_SENSE_IO = false
#endif
#option USB_BUS_SENSE_IO = false    ' board supports true
#option USB_BUS_SENSE_PIN = PORTA.1
public dim USB_BUS_SENSE_IN as USB_BUS_SENSE_PIN.bits(USB_BUS_SENSE_PIN@)

//
//-----------------------------------------------------------------------------
// userInit() - setup IO pins and other req'd regs
//-----------------------------------------------------------------------------
//
public sub userInit()

    // all digital pins except RA0 (potentiometer)
    ANSELA  = %00000001
    ANSELB  = %00000000
    ANSELC  = %00000000
    ANSELD  = %00000000
    ANSELE  = %00000000

    // analog comparators off
    CM1CON0 = 0
    CM2CON0 = 0

    // init leds & switch
    low(LED1)
    low(LED2)
    input(INPUT_SW)

    // usb VBUS detect
  #if (USB_BUS_SENSE_IO)
    input(USB_BUS_SENSE_IN)
  #endif

    // self power sense
  #if (SELF_POWER_SENSE_IO)
    input(SELF_POWER_SENSE_IN)
  #endif
end sub

//
//-----------------------------------------------------------------------------
// userClockCheck() - toggle led at 1ms rate to verify clock setting
//-----------------------------------------------------------------------------
//
public sub userClockCheck()
    while(true)
        LED1 = 1
        delayus(500)
        LED1 = 0
        delayus(500)
    end while
end sub

end module
