//
//-----------------------------------------------------------------------------
// Sparkfun USB Bit Whacker v1.2 18F2553 DEV-00762 (www.sparkfun.com)
//-----------------------------------------------------------------------------
//
module user_init

#define USB_WHACKER

//
//-----------------------------------------------------------------------------
// config settings
//-----------------------------------------------------------------------------
//
// 18F2553 w/24MHz external xtal
config
    FOSC = HSPLL_HS,        // external 24MHz xtal w/PLL
    PLLDIV = 6,             // PLL prescaler 24/6=4MHz
    CPUDIV = OSC1_PLL2,     // 48MHz cpu clock (96MHz/2)
    USBDIV = 2,             // 48MHz usb clock (96MHz/2)
    FCMEN = OFF,
    IESO = OFF,
    PWRT = ON,
    BOR = OFF,
    BORV = 2,
    VREGEN = ON,
    WDT = OFF,
    WDTPS = 2048,
    CCP2MX = OFF,
    PBADEN = OFF,
    LPT1OSC = OFF,
    MCLRE = ON
    
//
//-----------------------------------------------------------------------------
// usb whacker hardware
//-----------------------------------------------------------------------------
// usb powered only  (5V USB VBUS tied directly to VDD)
// no USB VBUS detect
// clock setup via config settings only (see above)
//
public dim LED1     as PORTC.0      // SL1 LED2 (yellow)
public dim LED2     as PORTC.1      // SL2 LED3 (red)
public dim INPUT_SW as PORTC.2      // sw S2 (marked PRG) w/ext 10K pullup

// power options
#option USB_SELF_POWER = 0          // 0=bus-powered, 1=self-powered
#option SELF_POWER_SENSE_IO = false

// USB VBUS detect
#option USB_BUS_SENSE_IO = false

//
//-----------------------------------------------------------------------------
// userInit() - setup IO pins and other req'd regs
//-----------------------------------------------------------------------------
//
public sub userInit()

  #if (_device = 18F2553)   ' some ubw versions use a different chip
    ADCON1 = %00001111      ' all digital (disable A/D on all pins)
    CMCON = %00000000       ' disable comparators
    CVRCON = $00            ' and turn off reference
  #endif

    // init leds & switch
    low(LED1)
    low(LED2)
    input(INPUT_SW)
end sub

//
//-----------------------------------------------------------------------------
// userClockCheck() - toggle led at 1ms rate to verify clock setting
//-----------------------------------------------------------------------------
//
public sub userClockCheck()
    while(true)
        LED1 = 1
        delayus(500)
        LED1 = 0
        delayus(500)
    end while
end sub

end module
